@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.1500';
+our $VERSION = '0.1501';
 
 use MIDI::Simple;
 use Music::Duration;
@@ -345,7 +345,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.1500
+version 0.1501
 
 =head1 SYNOPSIS
 
@@ -592,11 +592,11 @@ If not provided the B<snare> is used for the B<patch>.
 
 =head2 crescendo_roll
 
-  $d->crescendo_roll( [$i, $j], $length, $spec, $patch );
+  $d->crescendo_roll( [$start, $span], $length, $spec, $patch );
 
 Add a drum roll to the score, where the B<patch> is played for
-duration B<length> in B<spec> increments at increasing or decreasing
-volumes from B<i> to B<j>.
+duration B<length> in B<spec> notes, at increasing or decreasing
+volumes from B<start> in B<span> increments.
 
 If not provided the B<snare> is used for the B<patch>.
 
